@@ -134,12 +134,12 @@ my %doc_for = (
             descr    => 'top level of Gantry::Conf file',
             sort_order => 10,
         },
-        GantryLocation => {
-            keyword  => 'GantryLocation',
-            label    => 'Root level config',
-            descr    => 'controller level of Gantry::Conf file',
-            sort_order => 20,
-        },
+#        GantryLocation => {
+#            keyword  => 'GantryLocation',
+#            label    => 'Root level config',
+#            descr    => 'controller level of Gantry::Conf file',
+#            sort_order => 20,
+#        },
         PerlTop => {
             keyword  => 'PerlTop',
             label    => 'Preamble',
@@ -275,6 +275,15 @@ my %doc_for = (
             quick_label => 'SQL Type',
             sort_order  => 30,
         },
+        accessor => {
+            keyword   => 'accessor',
+            label     => 'Accessor Name',
+            descr     => 'DBIx::Class alternate accessor name for this column',
+            type      => 'text',
+            multiple  => 1,
+            urgency   => 0,
+            sort_order => 35,
+        },
         refers_to => {
             keyword       => 'refers_to',
             label         => 'Foreign Key Table',
@@ -886,6 +895,21 @@ my %doc_for = (
                 main_listing => 1,
             },
         },
+        where_terms => {
+            keyword       => 'where_terms',
+            label         => 'Equality tests on listed columns',
+            descr         => 'Where clause will include these equality tests',
+            type          => 'pair',
+            pair_labels   => [ 'Table', 'Table' ],
+            pair_required => 1,
+            multiple      => 1,
+            urgency       => 0,
+            sort_order    => 69,
+            applies_to    => 'main listing',
+            method_types => {
+                main_listing => 1,
+            },
+        },
         title => {
             keyword     => 'title',
             label       => 'Browser Title',
